XML Attacks
-------

**Description:**

Whenever you are using XML in your application there are a few possibilities for 
injections depending on how you are applying XML in your system.

Extensible Markup Language (XML) is a markup language that defines a set of rules for 
encoding documents in a format which is both human-readable and machine-readable. It is 
defined by the W3C's XML 1.0 Specification and by several other related specifications,
all of which are free open standards.


**Solution:**

Items listed below are recommended to read whenever you are planning to use XML in your
application.

Recommended knowledge base items:

- XML injection
- External DTD parsing
- XSLT injections
- XPath injections
- XXE injections
